@@ -101,6 +101,8 @@ def _build_series(*args, interactive=False, **kwargs):
             # plotting a single expression
             add_series(args)
 
+
+        params = kwargs.get("params", dict())
         for a in new_args:
             expr, ranges, label = a[0], a[1:-1], a[-1]
 
@@ -110,7 +112,12 @@ def _build_series(*args, interactive=False, **kwargs):
             for i, r in enumerate(ranges):
                 ranges[i] = (r[0], complex(r[1]), complex(r[2]))
 
-            if expr.is_complex:
+            # there are expressions that are complex, but they do not represent
+            # complex points, for example `exp(I * phi)`. If it is a complex
+            # point, it won't have any free symbols.
+            fs = expr.free_symbols
+            fs = fs.difference(set(params.keys()))
+            if expr.is_complex and (len(fs) == 0):
                 # complex number with its own label
                 cls = ComplexPointSeries if not interactive else ComplexPointInteractiveSeries
                 series.append(cls([expr], label, **kwargs))
@@ -290,6 +297,9 @@ def plot_real_imag(*args, **kwargs):
         * callable: a function requiring one input element, the learner. It
           must return a float number. Refer to [#fn0]_ for more information.
 
+    arg : boolean, optional
+        If True, plot the argument of the complex function. Default to True.
+
     aspect : (float, float) or str, optional
         Set the aspect ratio of the plot. The value depends on the backend
         being used. Read that backend's documentation to find out the
@@ -299,18 +309,6 @@ def plot_real_imag(*args, **kwargs):
         A subclass of `Plot`, which will perform the rendering.
         Default to `MatplotlibBackend`.
 
-    loss_fn : callable or None
-        The loss function to be used by the `adaptive` learner.
-        Possible values:
-
-        * `None` (default): it will use the `default_loss` from the
-          `adaptive` module.
-        * callable : Refer to [#fn0]_ for more information. Specifically,
-          look at `adaptive.learner.learner1D` to find more loss functions.
-
-    arg : boolean, optional
-        If True, plot the argument of the complex function. Default to True.
-
     detect_poles : boolean, optional
         Chose whether to detect and correctly plot poles. Defaulto to False.
         It only works with line plots. To improve detection, increase the
@@ -330,6 +328,15 @@ def plot_real_imag(*args, **kwargs):
         A dictionary of keywords/values which is passed to the backend's function to customize the appearance of the lines. Refer to the
         plotting library (backend) manual for more informations.
 
+    loss_fn : callable or None
+        The loss function to be used by the `adaptive` learner.
+        Possible values:
+
+        * `None` (default): it will use the `default_loss` from the
+          `adaptive` module.
+        * callable : Refer to [#fn0]_ for more information. Specifically,
+          look at `adaptive.learner.learner1D` to find more loss functions.
+
     modules : str, optional
         Specify the modules to be used for the numerical evaluation. Refer to
         `lambdify` to visualize the available options. Default to None,
@@ -352,6 +359,15 @@ def plot_real_imag(*args, **kwargs):
     show : boolean, optional
         Default to True, in which case the plot will be shown on the screen.
 
+    size : (float, float), optional
+        A tuple in the form (width, height) to specify the size of
+        the overall figure. The default value is set to `None`, meaning
+        the size will be set by the backend.
+
+    surface_kw : dict, optional
+        A dictionary of keywords/values which is passed to the backend's function to customize the appearance of surfaces. Refer to the
+        plotting library (backend) manual for more informations.
+
     threed : boolean, optional
         It only applies to a complex function over a complex range. If False,
         contour plots will be shown. If True, 3D surfaces will be shown.
@@ -362,6 +378,34 @@ def plot_real_imag(*args, **kwargs):
         If True, a color map highlighting the elevation will be used.
         Default to True.
 
+    title : str, optional
+        Title of the plot. It is set to the latex representation of
+        the expression, if the plot has only one expression.
+
+    xlabel : str, optional
+        Label for the x-axis.
+
+    ylabel : str, optional
+        Label for the y-axis.
+
+    zlabel : str, optional
+        Label for the z-axis. Only available for 3D plots.
+
+    xscale : 'linear' or 'log', optional
+        Sets the scaling of the x-axis. Default to 'linear'.
+
+    yscale : 'linear' or 'log', optional
+        Sets the scaling of the y-axis. Default to 'linear'.
+
+    xlim : (float, float), optional
+        Denotes the x-axis limits, `(min, max)`.
+
+    ylim : (float, float), optional
+        Denotes the y-axis limits, `(min, max)`.
+
+    zlim : (float, float), optional
+        Denotes the z-axis limits, `(min, max)`. Only available for 3D plots.
+
 
     Examples
     ========
@@ -543,6 +587,10 @@ def plot_complex(*args, **kwargs):
         A subclass of `Plot`, which will perform the rendering.
         Default to `MatplotlibBackend`.
 
+    line_kw : dict, optional
+        A dictionary of keywords/values which is passed to the backend's function to customize the appearance of lines. Refer to the
+        plotting library (backend) manual for more informations.
+
     loss_fn : callable or None
         The loss function to be used by the `adaptive` learner.
         Possible values:
@@ -571,6 +619,11 @@ def plot_complex(*args, **kwargs):
     show : boolean, optional
         Default to True, in which case the plot will be shown on the screen.
 
+    size : (float, float), optional
+        A tuple in the form (width, height) to specify the size of
+        the overall figure. The default value is set to `None`, meaning
+        the size will be set by the backend.
+
     threed : boolean, optional
         It only applies to a complex function over a complex range. If False,
         a 2D image plot will be shown. If True, 3D surfaces will be shown.
@@ -616,6 +669,34 @@ def plot_complex(*args, **kwargs):
         Default value to 20. It controls the number of iso-phase and/or
         iso-modulus lines in domain coloring plots.
 
+    title : str, optional
+        Title of the plot. It is set to the latex representation of
+        the expression, if the plot has only one expression.
+
+    xlabel : str, optional
+        Label for the x-axis.
+
+    ylabel : str, optional
+        Label for the y-axis.
+
+    zlabel : str, optional
+        Label for the z-axis. Only available for 3D plots.
+
+    xscale : 'linear' or 'log', optional
+        Sets the scaling of the x-axis. Default to 'linear'.
+
+    yscale : 'linear' or 'log', optional
+        Sets the scaling of the y-axis. Default to 'linear'.
+
+    xlim : (float, float), optional
+        Denotes the x-axis limits, `(min, max)`.
+
+    ylim : (float, float), optional
+        Denotes the y-axis limits, `(min, max)`.
+
+    zlim : (float, float), optional
+        Denotes the z-axis limits, `(min, max)`. Only available for 3D plots.
+
 
     Examples
     ========
@@ -728,9 +809,45 @@ def plot_complex_list(*args, **kwargs):
         If True, a scatter plot will be produced. Otherwise a line plot will
         be created. Default to True.
 
+    is_filled : boolean, optional
+        Default to True, which will render empty circular markers. It only
+        works if `is_point=True`.
+        If False, filled circular markers will be rendered.
+
+    line_kw : dict, optional
+        A dictionary of keywords/values which is passed to the backend's function to customize the appearance of lines. Refer to the
+        plotting library (backend) manual for more informations.
+
     show : boolean
         Default to True, in which case the plot will be shown on the screen.
 
+    size : (float, float), optional
+        A tuple in the form (width, height) to specify the size of
+        the overall figure. The default value is set to `None`, meaning
+        the size will be set by the backend.
+
+    title : str, optional
+        Title of the plot. It is set to the latex representation of
+        the expression, if the plot has only one expression.
+
+    xlabel : str, optional
+        Label for the x-axis.
+
+    ylabel : str, optional
+        Label for the y-axis.
+
+    xscale : 'linear' or 'log', optional
+        Sets the scaling of the x-axis. Default to 'linear'.
+
+    yscale : 'linear' or 'log', optional
+        Sets the scaling of the y-axis. Default to 'linear'.
+
+    xlim : (float, float), optional
+        Denotes the x-axis limits, `(min, max)`.
+
+    ylim : (float, float), optional
+        Denotes the y-axis limits, `(min, max)`.
+
 
     Examples
     ========
@@ -873,6 +990,11 @@ def plot_complex_vector(*args, **kwargs):
         the `Plot` class can then be used to save or display the plot
         by calling the `save()` and `show()` methods respectively.
 
+    size : (float, float), optional
+        A tuple in the form (width, height) to specify the size of
+        the overall figure. The default value is set to `None`, meaning
+        the size will be set by the backend.
+
     streamlines : boolean
         Whether to plot the vector field using streamlines (True) or quivers
         (False). Default to False.
@@ -882,6 +1004,28 @@ def plot_complex_vector(*args, **kwargs):
         streamlines-plotting function to customize the appearance. Refer to
         the plotting library (backend) manual for more informations.
 
+    title : str, optional
+        Title of the plot. It is set to the latex representation of
+        the expression, if the plot has only one expression.
+
+    xlabel : str, optional
+        Label for the x-axis.
+
+    ylabel : str, optional
+        Label for the y-axis.
+
+    xscale : 'linear' or 'log', optional
+        Sets the scaling of the x-axis. Default to 'linear'.
+
+    yscale : 'linear' or 'log', optional
+        Sets the scaling of the y-axis. Default to 'linear'.
+
+    xlim : (float, float), optional
+        Denotes the x-axis limits, `(min, max)`.
+
+    ylim : (float, float), optional
+        Denotes the y-axis limits, `(min, max)`.
+
 
     Examples
     ========
