@@ -303,13 +303,248 @@ class PanelLayout:
             return pn.Row(self.view, self.layout_controls)
 
 
-class InteractivePlot(DynamicParam, PanelLayout):
-    """Contains all the logic to create parametric-interactive plots."""
+def create_series(*args, **kwargs):
+    """
+    Create interactive data series, ie. series whose numerical data depends
+    on the expression and all its parameters.
 
-    # NOTE: why isn't Plot a parent class for InteractivePlot?
-    # If that was the case, we would need to create multiple subclasses of
-    # InteractivePlot, each one targeting a different backend.
-    # Instead, we keep the backend (the actual plot) as an instance attribute.
+    Typical usage examples are in the followings:
+
+    - Create a single interactive series:
+        `create_series([expr, range], **kwargs)`
+    - Create multiple interactive series:
+        `create_series([(expr1, range1), (expr2, range2)], **kwargs)`
+
+    The correct series type is instantiated only if all ranges are specified.
+    So, to create an interactive line series, one range must be specified.
+    To create an interactive surface series, two ranges must be provided, and
+    so on.
+
+    Notes
+    =====
+
+    The keyword arguments to be provided depends on the interested data series
+    to be created. For example, if we are trying to plot a line, then the
+    same keyword argument associated to the ``plot()`` function can be used.
+    Similarly, if we are trying to create vector-related interactive series,
+    the same keyword arguments associated to ``plot_vector()`` can be used.
+    And so on.
+
+    However, interactive data series do not support adaptive algorithms.
+    Hence, adaptive-related keyword arguments will not be used.
+
+    Parameters
+    ==========
+
+    args : list/tuple
+
+        A list or tuple of the form ``[(expr1, range1), ...]``, where:
+
+        expr : Expr
+            Expression (or expressions) representing the function to evaluate.
+
+        range: (symbol, min, max)
+            A 3-tuple (or multiple 3-tuple) denoting the range of the
+            variable. For the function to work properly, all ranges must be
+            provided.
+
+    params : dict
+        A dictionary mapping symbols to numerical values. If not specified,
+        ``iplot`` should be provided instead.
+
+    iplot : InteractivePlot, optional
+        An existing instance of ``InteractivePlot`` from which the parameters
+        will be extracted. If both ``params`` and ``iplot`` are provided, then
+        ``iplot`` has the precedence.
+
+    is_complex : boolean, optional
+        Default to False. If True, it directs the internal algorithm to
+        create all the necessary series to create a complex plot (for example,
+        one for the real part, one for the imaginary part, ...).
+
+    is_vector : boolean, optional
+        Default to False. If True, it directs the internal algorithm to
+        create all the necessary series to create a vector plot (for example,
+        plotting the magnitude of the vector field as a contour plot, ...).
+
+    n1, n2, n3 : int, optional
+        Number of discretization points in the 3 directions.
+
+    n : int, optional
+        Set the same number of discretization points on all directions.
+
+
+    Returns
+    =======
+
+    s : list
+        A list of interactive data series.
+
+
+    Examples
+    ========
+
+    >>> from sympy import (symbols, pi, sin, cos, exp, Plane,
+    ...     Matrix, gamma, I, sqrt, Abs)
+    >>> from spb.interactive import create_series
+    >>> u, v, x, y, z = symbols('u, v, x:z')
+
+    2D line interactive series:
+
+    >>> s = create_series((u * sqrt(x), (x, -5, 5)), params={u: 1})
+    >>> print(len(s), type(s[0]))
+    (1, spb.series.LineInteractiveSeries)
+
+    2D parametric line interactive series:
+
+    >>> s = create_series((u * cos(x), u * sin(x), (x, -5, 5)), params={u: 1})
+    >>> len(s), type(s[0])
+    (1, spb.series.Parametric2DLineInteractiveSeries)
+
+    Multiple 2D lines interactive series:
+
+    >>> s = create_series(
+    ...     (u * sqrt(x), (x, -5, 5)),
+    ...     (cos(u * x), (x, -3, 3)),
+    ...     params={u: 1})
+    >>> len(s), type(s[0]), type(s[1])
+    (2, spb.series.LineInteractiveSeries, spb.series.LineInteractiveSeries)
+
+    Surface interactive series:
+
+    >>> s = create_series((cos(x**2 + u * y**2), (x, -5, 5), (y, -5, 5)),
+    ...     params={u: 1}, threed=True)
+    >>> len(s), type(s[0])
+    (1, spb.series.SurfaceInteractiveSeries)
+
+    Contour interactive series:
+
+    >>> s = create_series((cos(x**2 + u * y**2), (x, -5, 5), (y, -5, 5)),
+    ...     params={u: 1}, threed=False)
+    >>> len(s), type(s[0])
+    (1, spb.series.ContourInteractiveSeries)
+
+    Interactive series of the absolute value of a complex function colored
+    by its argument over a real domain. Note that we are passing
+    ``is_complex=True``:
+
+    >>> s = create_series((u * sqrt(x), (x, -5, 5)), params={u: 1},
+    ...     is_complex=True)
+    >>> len(s), type(s[0])
+    (1, spb.series.AbsArgLineInteractiveSeries)
+
+    Real and imaginary parts of a complex function over a real domain:
+
+    >>> s = create_series((u * sqrt(x), (x, -5, 5)), params={u: 1},
+    ...     is_complex=True, absarg=False, real=True, imag=True)
+    >>> len(s), type(s[0]), type(s[1])
+    (2, spb.series.LineInteractiveSeries, spb.series.LineInteractiveSeries)
+
+    Complex domain coloring interactive series:
+
+    >>> s = create_series((u * sqrt(x), (x, -5-5j, 5+5j)), params={u: 1},
+    ...     is_complex=True)
+    >>> len(s), type(s[0])
+
+    Real and imaginary parts of a complex function over a complex domain:
+
+    >>> s = create_series((u * sqrt(x), (x, -5-5j, 5+5j)), params={u: 1},
+    ...     is_complex=True, threed=True, absarg=False, real=True, imag=True)
+    >>> len(s), type(s[0]), type(s[1])
+    (2, spb.series.ComplexSurfaceInteractiveSeries, spb.series.ComplexSurfaceInteractiveSeries)
+
+    2D vector interactive series (only quivers):
+
+    >>> from sympy.vector import CoordSys3D
+    >>> N = CoordSys3D("N")
+    >>> i, j, k = N.base_vectors()
+    >>> x, y, z = N.base_scalars()
+    >>> a, b, c = symbols("a:c")
+    >>> v1 = -a * sin(y) * i + b * cos(x) * j
+    >>> s = create_series((v1, (x, -5, 5), (y, -4, 4)),
+    ...     params={a: 2, b: 3}, is_vector=False)
+    >>> len(s), type(s[0])
+    (1, spb.series.Vector2DInteractiveSeries)
+
+    2D vector interactive series (contour + quivers):
+
+    >>> s = create_series((v1, (x, -5, 5), (y, -4, 4)),
+    ...     params={a: 2, b: 3}, is_vector=True)
+    >>> len(s), type(s[0]), type(s[1])
+    (2, spb.series.ContourInteractiveSeries, spb.series.Vector2DInteractiveSeries)
+
+    Sliced 3D vector (single slice):
+
+    >>> from sympy import Plane
+    >>> v3 = a * z * i + b * y * j + c * x * k
+    >>> s = create_series((v3, (x, -5, 5), (y, -4, 4), (z, -6, 6)),
+    ...     params={a: 2, b: 3, c: 1}, slice=Plane((1, 2, 3), (1, 0, 0)))
+    >>> len(s), type(s[0])
+    (1, spb.series.SliceVector3DInteractiveSeries)
+
+    Geometry interactive series:
+
+    >>> from sympy import Circle
+    >>> s = create_series((Circle((0, 0), u), ), params={u: 1})
+    >>> len(s), type(s[0])
+    (1, spb.series.GeometryInteractiveSeries)
+
+    See also
+    ========
+
+    iplot, create_widgets
+
+    """
+    args = list(map(_plot_sympify, args))
+
+    iplot_obj = kwargs.pop("iplot", None)
+    if iplot_obj is not None:
+        # read the parameters to generate the initial numerical data for
+        # the interactive series
+        kwargs["params"] = iplot_obj.read_parameters()
+
+    kwargs = _set_discretization_points(kwargs, InteractiveSeries)
+    _slice = kwargs.get("slice", None)
+    is_complex = kwargs.get("is_complex", False)
+    is_vector = kwargs.get("is_vector", False)
+    series = []
+    if is_complex:
+        new_args = []
+        for a in args:
+            exprs, ranges, label = _unpack_args(
+                *a, matrices=False, fill_ranges=False
+            )
+            new_args.append(Tuple(exprs[0], *ranges, label, sympify=False))
+        series = _build_complex_series(*new_args, interactive=True, **kwargs)
+    elif is_vector:
+        args = _preprocess(*args, matrices=False, fill_ranges=False)
+        series = _build_vector_series(*args, interactive=True, **kwargs)
+    else:
+        for a in args:
+            # with interactive-parametric plots, vectors could have more
+            # free symbols than the number of dimensions. We set
+            # fill_ranges=False in order to not fill ranges, otherwise
+            # ranges will be created also for parameters. This means
+            # the user must provided all the necessary ranges.
+            exprs, ranges, label = _unpack_args(
+                *a, matrices=True, fill_ranges=False
+            )
+            if isinstance(_slice, (tuple, list)):
+                # Sliced 3D vector field: each slice creates a
+                # unique series
+                kwargs2 = kwargs.copy()
+                kwargs2.pop("slice")
+                for s in _slice:
+                    kwargs2["slice"] = s
+                    series.append(
+                        InteractiveSeries(exprs, ranges, label, **kwargs2)
+                    )
+            else:
+                series.append(InteractiveSeries(exprs, ranges, label, **kwargs))
+    return series
+
+
+class InteractivePlot(DynamicParam, PanelLayout):
 
     def __new__(cls, *args, **kwargs):
         return object.__new__(cls)
@@ -332,65 +567,20 @@ class InteractivePlot(DynamicParam, PanelLayout):
 
         layout = kwargs.pop("layout", "tb")
         ncols = kwargs.pop("ncols", 2)
-        throttled = kwargs.pop("throttled", False)
+        throttled = kwargs.pop("throttled", cfg["interactive"]["throttled"])
         use_latex = kwargs.pop("use_latex", cfg["interactive"]["use_latex"])
 
-        args = list(map(_plot_sympify, args))
         super().__init__(*args, name=name, params=params, use_latex=use_latex)
         PanelLayout.__init__(self, layout, ncols, throttled)
 
         # create the series
-        series = self._create_series(*args, **kwargs)
+        series = create_series(*args, iplot=self, **kwargs)
         is_3D = all([s.is_3D for s in series])
         # create the plot
         Backend = kwargs.pop("backend", THREE_D_B if is_3D else TWO_D_B)
         kwargs["is_iplot"] = True
         self._backend = Backend(*series, **kwargs)
 
-    def _create_series(self, *args, **kwargs):
-        # read the parameters to generate the initial numerical data for
-        # the interactive series
-        kwargs["params"] = self.read_parameters()
-        kwargs = _set_discretization_points(kwargs, InteractiveSeries)
-        _slice = kwargs.get("slice", None)
-        is_complex = kwargs.get("is_complex", False)
-        is_vector = kwargs.get("is_vector", False)
-        series = []
-        if is_complex:
-            new_args = []
-            for a in args:
-                exprs, ranges, label = _unpack_args(
-                    *a, matrices=False, fill_ranges=False
-                )
-                new_args.append(Tuple(exprs[0], *ranges, label, sympify=False))
-            series = _build_complex_series(*new_args, interactive=True, **kwargs)
-        elif is_vector:
-            args = _preprocess(*args, matrices=False, fill_ranges=False)
-            series = _build_vector_series(*args, interactive=True, **kwargs)
-        else:
-            for a in args:
-                # with interactive-parametric plots, vectors could have more
-                # free symbols than the number of dimensions. We set
-                # fill_ranges=False in order to not fill ranges, otherwise
-                # ranges will be created also for parameters. This means
-                # the user must provided all the necessary ranges.
-                exprs, ranges, label = _unpack_args(
-                    *a, matrices=True, fill_ranges=False
-                )
-                if isinstance(_slice, (tuple, list)):
-                    # Sliced 3D vector field: each slice creates a
-                    # unique series
-                    kwargs2 = kwargs.copy()
-                    kwargs2.pop("slice")
-                    for s in _slice:
-                        kwargs2["slice"] = s
-                        series.append(
-                            InteractiveSeries(exprs, ranges, label, **kwargs2)
-                        )
-                else:
-                    series.append(InteractiveSeries(exprs, ranges, label, **kwargs))
-        return series
-
     @property
     def fig(self):
         """Return the plot object"""
@@ -740,8 +930,11 @@ def iplot(*args, show=True, **kwargs):
        sign.
     3. `show=False` has been set in order for ``iplot`` to return an instance
        of ``InteractivePlot``, which supports addition.
+    4. Once we are done playing with parameters, we can access the backend
+       with ``p.backend``. Then, we can use the ``p.backend.fig`` attribute
+       to retrieve the figure, or ``p.backend.save()`` to save the figure.
 
-    .. code-block:: python
+    .. jupyter-execute::
 
        from spb.functions import plot
        u = symbols("u")
@@ -756,7 +949,8 @@ def iplot(*args, show=True, **kwargs):
            ylabel = "y1",
            title = "title 1",
            legend = True,
-           show = False
+           show = False,
+           use_latex = False
        )
        p2 = iplot(
            (sin(u * x), (x, -5, 5)),
@@ -889,6 +1083,12 @@ def iplot(*args, show=True, **kwargs):
 
     .. [#fn1] https://docs.bokeh.org/en/latest/docs/user_guide/styling.html#tick-label-formats
 
+
+    See also
+    ========
+
+    create_series, create_widgets
+
     """
     i = InteractivePlot(*args, **kwargs)
     if show:
@@ -968,6 +1168,12 @@ def create_widgets(params, **kwargs):
 
     .. [#fn2] https://panel.holoviz.org/user_guide/Param.html
 
+
+    See also
+    ========
+
+    iplot, create_series
+
     """
     dp = DynamicParam(params=params, **kwargs)
     tmp_panel = pn.Param(dp)
